@@ -1,4 +1,5 @@
 import re
+import threading
 
 from typing import Callable
 from jaaql.email.email_manager_service import Email, TYPE__email_attachments
@@ -7,6 +8,7 @@ from os.path import join
 from jaaql.exceptions.http_status_exception import HttpStatusException
 from jaaql.constants import *
 from urllib.parse import quote
+import time
 
 REGEX__email_parameter = r'({{)([a-zA-Z0-9_\-]+)(}})'
 REGEX__email_uri_encoded_parameter = r'(\[\[)([a-zA-Z0-9_\-]+)(\]\])'
@@ -21,9 +23,13 @@ class EmailManager:
     def send_email(self, email: Email):
         requests.post("http://127.0.0.1:" + str(PORT__ems) + ENDPOINT__send_email, json=email.repr_json())
 
-    def reload_service(self):
+    def wait_and_then_reload_service(self):
+        time.sleep(0.5)
         requests.post("http://127.0.0.1:" + str(PORT__ems) + ENDPOINT__reload_accounts)
 
+    def reload_service(self):
+        threading.Thread(target=self.wait_and_then_reload_service).start()
+
     @staticmethod
     def uri_encode_replace(val):
         return quote(str(val))
